#############################################################
#############################################################
## Replicate Graphs
## Ahn, Esarey, and Scholz
## Reputation and Cooperation in Voluntary Exchanges
## November 20, 2008
#############################################################
#############################################################


#########################
## Read in dataset     ##
#########################

require(foreign)
mergedmonadic<-read.dta("merged monadic.dta")


#########################
## Create Figure 1     ##
#########################

# subset data into global/central, local, and baseline treatmnts

global.data<-subset(mergedmonadic, treatmnt==2)
local.data<-subset(mergedmonadic, treatmnt==1)
base.data<-subset(mergedmonadic, treatmnt==0)

par(mfrow=c(2,2))

# Create Plot of Avg. % of Cooperative Links

timeseries.global<-subset(global.data, select=c(percentc, profit, links, period, sesidnum))
timeseries.global$sesidnum<-factor(timeseries.global$sesidnum)
timeseries.global$treatmnt<-rep(1,dim(timeseries.global)[1])
timeseries.local<-subset(local.data, select=c(percentc, profit, links, period, sesidnum))
timeseries.local$sesidnum<-factor(timeseries.local$sesidnum)
timeseries.local$treatmnt<-rep(2,dim(timeseries.local)[1])
timeseries.base<-subset(base.data, select=c(percentc, profit, links, period, sesidnum))
timeseries.base$sesidnum<-factor(timeseries.base$sesidnum)
timeseries.base$treatmnt<-rep(0,dim(timeseries.base)[1])
timeseries<-rbind(timeseries.global,timeseries.local,timeseries.base)
attach(timeseries)
percentcplotdata<-by(timeseries[,1], list(period=period, treatmnt=treatmnt), mean, na.rm=TRUE)
earningsplotdata<-by(timeseries[,2], list(period=period, treatmnt=treatmnt), mean, na.rm=TRUE)
linksplotdata<-by(timeseries[,3], list(period=period, treatmnt=treatmnt), mean, na.rm=TRUE)

detach(timeseries)

plot(percentcplotdata[,1],type="l", ylim=c(0,1), xlab="Period", ylab="Average % of C Plays", main="Average % of C Plays")
lines(percentcplotdata[,2], type="l", lty=2)
lines(percentcplotdata[,3], type="l", lty=3)
legend("topleft", legend=c("Baseline","Central","Local"), lty=1:3)


# Create Plot of Average Earnings

plot(earningsplotdata[,1],type="l", ylim=c(0,300), xlab="Period", ylab="Average Earnings", main="Average Earnings")
lines(earningsplotdata[,2], type="l", lty=2)
lines(earningsplotdata[,3], type="l", lty=3)



# Create Plot of # of CC Links

attach(base.data)
ccframebase<-data.frame(cbind(numbrfcc,period,sesidnum))
ccframebase$treatmnt<-rep(0,dim(ccframebase)[1])
detach(base.data)

attach(global.data)
ccframeglobal<-data.frame(cbind(numbrfcc,period,sesidnum))
ccframeglobal$treatmnt<-rep(1,dim(ccframeglobal)[1])
detach(global.data)

attach(local.data)
ccframelocal<-data.frame(cbind(numbrfcc,period,sesidnum))
ccframelocal$treatmnt<-rep(2,dim(ccframelocal)[1])
detach(local.data)

ccframe<-data.frame(rbind(ccframebase, ccframeglobal, ccframelocal))
attach(ccframe)
ccplotdata<-by(ccframe[,1], list(period=period, treatmnt=treatmnt), mean, na.rm=TRUE)
detach(ccframe)

plot(ccplotdata[,1],type="l", ylim=c(0,5), xlab="Period", ylab="Average # CC Links", main="Average # CC Links")
lines(ccplotdata[,2], type="l", lty=2)
lines(ccplotdata[,3], type="l", lty=3)
#legend("topleft", legend=c("Baseline","Central","Local"), lty=1:3)



# Create Plot of Avg # of Links

plot(linksplotdata[,1],type="l", ylim=c(0,8), xlab="Period", ylab="Average # of Links", main="Average # of Links")
lines(linksplotdata[,2], type="l", lty=2)
lines(linksplotdata[,3], type="l", lty=3)


#####################################################
## Unreported Figure: Global vs. Global Truthful   ##
#####################################################

mergedmonadicwgt<-read.dta("merged monadic with global truthful.dta")
global.t.data<-subset(mergedmonadicwgt, treatmnt==3)


par(mfrow=c(2,2))

# Create Plot of Avg. % of Cooperative Links

timeseries.global<-subset(global.data, select=c(percentc, profit, links, period, sesidnum))
timeseries.global$session<-factor(timeseries.global$sesidnum)
timeseries.global$treatmnt<-rep(0,dim(timeseries.global)[1])
timeseries.global.t<-subset(global.t.data, select=c(percentc, profit, links, period, sesidnum))
timeseries.global.t$session<-factor(timeseries.global.t$sesidnum)
timeseries.global.t$treatmnt<-rep(1,dim(timeseries.global.t)[1])

timeseries<-rbind(timeseries.global,timeseries.global.t)
attach(timeseries)
percentcplotdata<-by(timeseries[,1], list(period=period, treatmnt=treatmnt), mean, na.rm=TRUE)
earningsplotdata<-by(timeseries[,2], list(period=period, treatmnt=treatmnt), mean, na.rm=TRUE)
linksplotdata<-by(timeseries[,3], list(period=period, treatmnt=treatmnt), mean, na.rm=TRUE)
detach(timeseries)

plot(percentcplotdata[,1],type="l", ylim=c(0,1), xlab="Period", ylab="Average % of C Plays", main="Average % of C Plays")
lines(percentcplotdata[,2], type="l", lty=2)
legend("topleft", legend=c("Central Voluntary","Central Truthful"), lty=1:2)


# Create Plot of Average Earnings

plot(earningsplotdata[,1],type="l", ylim=c(0,300), xlab="Period", ylab="Average Earnings", main="Average Earnings")
lines(earningsplotdata[,2], type="l", lty=2)



# Create Plot of # of CC Links

attach(global.data)
ccframeglobal<-data.frame(cbind(numbrfcc,period))
ccframeglobal$treatmnt<-rep(0,dim(ccframeglobal)[1])
detach(global.data)


attach(global.t.data)
ccframeglobalt<-data.frame(cbind(numbrfcc,period))
ccframeglobalt$treatmnt<-rep(1,dim(ccframeglobalt)[1])
detach(global.t.data)


ccframe<-data.frame(rbind(ccframeglobal, ccframeglobalt))
attach(ccframe)
ccplotdata<-by(ccframe[,1], list(period=period, treatmnt=treatmnt), mean, na.rm=TRUE)
detach(ccframe)

plot(ccplotdata[,1],type="l", ylim=c(0,5), xlab="Period", ylab="Average # CC Links", main="Average # CC Links")
lines(ccplotdata[,2], type="l", lty=2)



# Create Plot of Avg # of Links

plot(linksplotdata[,1],type="l", ylim=c(0,8), xlab="Period", ylab="Average # of Links", main="Average # of Links")
lines(linksplotdata[,2], type="l", lty=2)





